==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/Chime/CreateAccount.pm <==

package Paws::Chime::CreateAccount;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/console/accounts');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Chime::CreateAccountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Chime::CreateAccount - Arguments for method CreateAccount on L<Paws::Chime>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateAccount on the
L<Amazon Chime|Paws::Chime> service. Use the attributes of this class
as arguments to method CreateAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateAccount.

=head1 SYNOPSIS

    my $chime = Paws->service('Chime');
    my $CreateAccountResponse = $chime->CreateAccount(
      Name => 'MyAccountName',

    );

    # Results:
    my $Account = $CreateAccountResponse->Account;

    # Returns a L<Paws::Chime::CreateAccountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/chime/CreateAccount>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the Amazon Chime account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateAccount in L<Paws::Chime>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/Chime/CreateAccount.pm <==

package Paws::Chime::CreateAccount;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateAccount');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/accounts');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Chime::CreateAccountResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Chime::CreateAccount - Arguments for method CreateAccount on L<Paws::Chime>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateAccount on the
L<Amazon Chime|Paws::Chime> service. Use the attributes of this class
as arguments to method CreateAccount.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateAccount.

=head1 SYNOPSIS

    my $chime = Paws->service('Chime');
    my $CreateAccountResponse = $chime->CreateAccount(
      Name => 'MyAccountName',

    );

    # Results:
    my $Account = $CreateAccountResponse->Account;

    # Returns a L<Paws::Chime::CreateAccountResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/chime/CreateAccount>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the Amazon Chime account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateAccount in L<Paws::Chime>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
